#****************************************************************************
#
#                              er_specs.std
#
#****************************************************************************
#
#   Property of Cummins Engine Company, Inc.
#
#   PURPOSE:
#      The er_specs file is used to carry out many tasks by the receipt
#      of a single event.  The event name specified in er_specs is usually
#      generated in gen_labels, do_specs, limit_specs, inpt_specs, and/or
#      gp_test.
#      Any event can be used. To find which events are being used by ASSET
#      you can type evnt_info on the command line of screen 6, 8, or 9.
#
#      This is a standard er_specs file to be copied out to new
#      installations.  This file has been reviewed for content by
#      the standards committee.
#
#   DOCUMENTATION:
#
#      Add this when we have some and know how to reference it from
#      the Access database.
#
#   HISTORY:
#
#
#      08-02-95 - bet - An example of an older change description.
#
#      08/30/96 - mjh - Added comments to the purpose section.
#                       Also added an IF_FALSE to the engine_cool section.
#                       This will only enable turning off the xducer pump if
#                       the engine is shutoff.
#      
#      Initial Release - B. E. Thomason - 01 Sept 1994
#
#******************************************************************************

#******************************************************************************
#
#  This is a specification file for the Event Response task - "evnt_rsp"
#
#  The Event Response task ("evnt_rsp") is normally spawned in the "go" 
#  script or can be spawned in the background from the command line. 
#  Only one version of "evnt_rsp" should be running at a time.  
#
#  After initialization, the task will wait for configuration messages
#  from the specification task "er_specs".  
#
#  The specification task ("er_specs") first sends a configuration message
#  to "evnt_rsp" requesting that it suspend operations and delete all
#  previous specifications, then it will read this file and transmit
#  each specification as a configuration message.  When it has read all
#  the way through the file, it will send a message to "evnt_rsp" to
#  begin handling the specifications.
#
#  NOTE:  The above is for general information.  The user will not
#         normally be responsible for how the Event Response task gets
#         started.  It can be assumed to always be present in an ASSET system.
#
#******************************************************************************
#
#                          Format of the file 
#
#     any line which begins with a  #  symbol is a comment (as is this line)
#
#     blank lines are ignored 
#
#     lines which begin with the  @  symbol are keywords
#
#     Keywords are used to define to "er_specs" what type of information follows
#     the keyword.  In many cases, there may be several lines of information
#     following a keyword.  If the keyword ends in "LIST" it means there
#     may be several lines of information entered, otherwise a single line
#     of information is to be entered.
#
#     The only keywords which are required are @INPUT_EVENT and @END
#
#     @INPUT_EVENT is always the first keyword in a specification and
#     @END is always the last keyword.  There is no data entered
#     after the @END keyword.
#
#     Other keywords may appear in any order between @INPUT_EVENT and
#     @END
#
#     If a particular parameter is not required, the keyword does not have
#     to appear in the specification.
#
#     Up to 64 specifications may be entered in a file
#
#******************************************************************************
#
#         Valid keywords and their use are described below:
#
#     @INPUT_EVENT         the name of the event which will trigger the
#                          action implied by the specification
#
#     @IF_TRUE_LIST        a list of variables of type LOGICAL_VARIABLE
#                          which must be TRUE for the action to be enabled
#
#     @IF_FALSE_LIST       a list of variables of type LOGICAL_VARIABLE
#                          which must be FALSE for the action to be enabled
#
#     @IF_SUCCESS_DESCRIPTION
#                          an 80 character description which will be written
#                          into a "display string" if the action is enabled
#
#     @IF_SUCCESS_DISPLAY  a code which defines where to write the
#                          80 character description of success
#                          Valid codes are:
#                             NOTIFY
#                             NOTIFY2
#                             NOTIFY3
#                             NOTIFY4
#                             SAFETY_MSG
#                             TEST_DESC
#                             TEST_DESC_2
#  
#     @IF_FAIL_DISPLAY     a code which defines where to write a
#                          description of the reason for failure to enable
#                          the specified actions.  This will be the names
#                          of the conditional variables which inhibited the
#                          action.
#
#     @LOG_ERROR_CODE      a code which defines the disposition of a system
#                          error message which will be generated if the action
#                          is inhibited.  
#                          Valid codes are:
#                             ERR_SCRN - log to ram file and red flag on screen
#                             ERR_LOG  - log only to ram file
#                             ERR_FILE - log only to hard disk file
#
#     @LOG_COMMENT         an 80 character comment line which will be logged
#                          into the file /data/errors/evnt_rsp
#
#     @SET_TRUE_LIST       a list of variable labels of type LOGICAL_VARIABLE 
#                          which will be set TRUE if action is enabled
#
#     @SET_FALSE_LIST      a list of variable labels of type LOGICAL_VARIABLE 
#                          which will be set FALSE if action is enabled
#
#     @SET_STATUS_LIST     a list of variable labels of any type which will
#                          be set to the "exception" status so that the
#                          display will blink if action is enabled
#
#     @RESET_STATUS_LIST   a list of variable labels of any type which will
#                          be set to the "normal" status so that the
#                          display will not blink if action is enabled
#
#     @SET_REAL_LIST       a list of variable labels and values of type
#                          REAL_VARIABLE which will be modified to the
#                          specified value if action is enabled
#
#     @SET_INTEGER_LIST    a list of variable labels and values of type
#                          INTEGER_VARIABLE which will be modified to the
#                          specified value if action is enabled
#
#     @OUTPUT_EVENT_LIST   a list of message event names to be sent if
#                          action is enabled.  The events are assumed to be
#                          of type ALARM_EVENT and will be created if they
#                          do not already exist.
#
#     @BACKGROUND_TASK     a single background process which will be spawned
#                          if action is enabled.  This may be a script file
#                          with multiple processes embedded in it.
#
#     @TRUE_ONE_SHOT_LIST  a list of variables of type LOGICAL_VARIABLE which
#                          are to be set true after specified time delays
#                          provided that the action is enabled at the time
#                          the input event is received.  The time delay is
#                          specified in milliseconds.  Each variable may have
#                          a unique time delay.
#
#     @FALSE_ONE_SHOT_LIST a list of variables of type LOGICAL_VARIABLE which
#                          are to be set false after specified time delays
#                          provided that the action is enabled at the time
#                          the input event is received.  The time delay is
#                          specified in milliseconds.  Each variable may have
#                          a unique time delay.
#
#******************************************************************************
#
# Classification of keywords:
#  input or trigger - this event must be received to process the spec
#     @INPUT_EVENT
#
#  conditionals - the states determine whether "actions" are enabled
#     @IF_TRUE_LIST
#     @IF_FALSE_LIST
#
#  action_enabled - the implied operation is taken if all of the conditional
#                   flags are satisfied
#     @SET_TRUE_LIST
#     @SET_FALSE_LIST
#     @SET_STATUS_LIST
#     @RESET_STATUS_LIST
#     @IF_SUCCESS_DISPLAY
#     @IF_SUCCESS_DESCRIPTION
#     @OUTPUT_EVENT_LIST
#     @SET_REAL_LIST
#     @SET_INTEGER_LIST
#     @TRUE_ONE_SHOT_LIST
#     @FALSE_ONE_SHOT_LIST
#     @BACKGROUND_TASK
#
#  action_disabled - the implied operation is taken if any of the conditional
#                    flags are not satisfied
#     @LOG_ERROR_CODE                                                         
#     @IF_FAIL_DISPLAY                                                        
#
#******************************************************************************
#
# CAUTION - actual specification data follows
#
#******************************************************************************

#******************************************************************************
# The "emergency" event is received when a critical limit specification is
# violated.  We will kill the engine and abort test.
#******************************************************************************

@INPUT_EVENT
emergency

@SET_TRUE_LIST
xducer_clnt
dyno_oil_pmp
beep 
TC_fans
dyn_coolant
#shop_air 

@SET_FALSE_LIST
starter
key_switch
ECM_power
fuel_fill
oil_cart_pwr
oil_cart_fll

@BACKGROUND_TASK
/asset/bin/th 0
/asset/bin/sp 1800

@END

#******************************************************************************

@INPUT_EVENT
abort_limit

@SET_TRUE_LIST
dyno_oil_pmp
beep 
TC_fans
shop_air 
dyn_coolant

@SET_FALSE_LIST
starter
fuel_fill
oil_cart_pwr
oil_cart_fll

@FALSE_ONE_SHOT_LIST
key_switch     2000
ECM_power      2000

@BACKGROUND_TASK
/asset/bin/th 0
/asset/bin/sp 1800

@END

#******************************************************************************

#@INPUT_EVENT
#flag_limit

#@SET_TRUE_LIST
#beep

#@END

#******************************************************************************

@INPUT_EVENT
cell_on_push

@IF_TRUE_LIST
start_enable

@IF_FALSE_LIST
flame_detect 
coolnt_level
coupling
fuel_tank
e_stop
idle_button
start_sense

@SET_TRUE_LIST
key_switch 
ECM_power
dyno_oil_pmp 
xducer_clnt
TC_fans
shop_air 
oil_cart_pwr
lamp_test
dyn_coolant

@SET_FALSE_LIST
beep 


@FALSE_ONE_SHOT_LIST
lamp_test       500

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Cell systems turned on...

@IF_FAIL_DISPLAY
NOTIFY

@END

#******************************************************************************

@INPUT_EVENT
cell_off_push

@SET_FALSE_LIST
starter
key_switch
dyno_oil_pmp
beep
TC_fans
fuel_fill
shop_air
int_rstr 
l_exh_rstr
#r_exh_rstr 
oil_cart_pwr
oil_cart_fll

@IF_FALSE_LIST
CalibrateECM

@FALSE_ONE_SHOT_LIST
ECM_power 30000

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Cell systems turned off...

#******************************************************************************

@INPUT_EVENT
start_push

@IF_TRUE_LIST
start_enable
trans_flow
key_sense
fan_status

@IF_FALSE_LIST
flame_detect 
coolnt_level
coupling
fuel_tank
dyn_clnt_flw
dyno_lube
e_stop
idle_button
start_select

@SET_TRUE_LIST
starter

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
STARTER BUTTON PUSHED - CRANKING!!!!

@IF_FAIL_DISPLAY
NOTIFY

@END

#******************************************************************************

@INPUT_EVENT
start_rels

@SET_FALSE_LIST
starter

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Starter button released...

@END

#******************************************************************************

@INPUT_EVENT
starter_enab

@RESET_STATUS_LIST
start_enable
 
@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
START switch inside test cell door switched to enable...

@END 

#******************************************************************************

@INPUT_EVENT
starter_dis

@SET_STATUS_LIST
start_enable

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
START switch inside test cell door switched to disable... 

@END

#****************************************************************************** 

@INPUT_EVENT
flame_detect

@OUTPUT_EVENT_LIST
emergency

@SET_STATUS_LIST
flame_detect

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
FLAME DETECTED - EMERGENCY SHUTDOWN!!!

@END

#******************************************************************************

@INPUT_EVENT
flame_out

@RESET_STATUS_LIST
flame_detect

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Flame out...

@END

#****************************************************************************** 

@INPUT_EVENT
clnt_level_lo

@IF_TRUE_LIST
key_sense

@OUTPUT_EVENT_LIST 
abort_limit 

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
LOW COOLANT - ABORTING TEST!! 

@SET_STATUS_LIST
coolnt_level
 
@END

#******************************************************************************

@INPUT_EVENT
clnt_level_ok

@RESET_STATUS_LIST
coolnt_level

@IF_SUCCESS_DESCRIPTION
Coolant level returned to normal...

@END

#******************************************************************************

@INPUT_EVENT
cplng_break

@IF_TRUE_LIST
key_sense

@OUTPUT_EVENT_LIST
emergency

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
COUPLING BREAK - EMERGENCY SHUTDOWN!!! 

@SET_STATUS_LIST
coupling

@END

#******************************************************************************

@INPUT_EVENT
cplng_ok

@RESET_STATUS_LIST
coupling

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Coupling OK...

@END

#******************************************************************************

@INPUT_EVENT
fuel_ovrflw

@OUTPUT_EVENT_LIST
abort_limit

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
FUEL TANK OVERFLOW - ABORTING TEST!! 

@SET_STATUS_LIST
fuel_tank
 
@END

#******************************************************************************

@INPUT_EVENT
fuel_normal

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Fuel Tank Level OK

@RESET_STATUS_LIST
fuel_tank

@END

#******************************************************************************

@INPUT_EVENT
dyno_flow_lo

@IF_TRUE_LIST
key_sense
dyn_coolant 

@OUTPUT_EVENT_LIST
abort_limit

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
DYNO COOLANT FLOW LOW - ABORTING TEST!! 

@SET_STATUS_LIST
dyn_clnt_flw
 
@END

#******************************************************************************

@INPUT_EVENT
dyno_flow_ok

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Dyno coolant flow ok...

@RESET_STATUS_LIST
dyn_clnt_flw

@END

#******************************************************************************
#Dyno does not have oil pump. for tc120 mjh 9/4/96
#******************************************************************************

@INPUT_EVENT
dyno_lube_lo

@IF_TRUE_LIST
key_sense

@OUTPUT_EVENT_LIST
abort_limit

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
DYNO LUBE PRESSURE LOW - ABORTING TEST!! 

@SET_STATUS_LIST
dyno_lube
 
@END

#******************************************************************************

@INPUT_EVENT
dyno_lube_ok

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Dyno lube pressure ok...

@RESET_STATUS_LIST
dyno_lube

@END

#******************************************************************************

@INPUT_EVENT
e_stop_push

@OUTPUT_EVENT_LIST
emergency

@SET_STATUS_LIST
e_stop

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
E_STOP - EMERGENCY SHUTDOWN!!! 

@END 
 
#******************************************************************************

@INPUT_EVENT
e_stop_rels

@RESET_STATUS_LIST
e_stop

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
e_stop reset...

@END 

#******************************************************************************

@INPUT_EVENT
idle_btn_push

@BACKGROUND_TASK
/specs/cmds/er_idle

@SET_STATUS_LIST
idle_button

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
idle button pushed...

@END 

#******************************************************************************

@INPUT_EVENT
idle_btn_rels

@RESET_STATUS_LIST
idle_button

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
idle button released...

@END 

#******************************************************************************

#@INPUT_EVENT
#fan_auto_fault

#@IF_TRUE_LIST
#key_sense

#@OUTPUT_EVENT_LIST
#abort_limit

#@IF_SUCCESS_DISPLAY
#NOTIFY

#@IF_SUCCESS_DESCRIPTION
#TC FAN AUTO FAULT - ABORTING TEST!! 

#@SET_STATUS_LIST
#fan_status
 
#@END

#******************************************************************************

#@INPUT_EVENT
#fan_auto_ok

#@IF_SUCCESS_DISPLAY
#NOTIFY

#@IF_SUCCESS_DESCRIPTION
#TC fan auto status normal...

#@RESET_STATUS_LIST
#fan_status

#@END

#******************************************************************************

@INPUT_EVENT
strt_sel_auto

@SET_FALSE_LIST
starter

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
SWITCH SET TO AUTO START...

@END

#******************************************************************************

@INPUT_EVENT
strt_sel_hand

@SET_FALSE_LIST
starter

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
SWITCH SET TO HAND START...

@END

#******************************************************************************

@INPUT_EVENT
engine_cool

@IF_FALSE_LIST
key_switch
SpeedGT400

@SET_FALSE_LIST
xducer_clnt

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
oil_pan_t below 150 F, xducer_clnt set OFF...

@END

###########################################################################

@INPUT_EVENT
trans_flow_lo

@IF_TRUE_LIST
key_switch 
           
@SET_TRUE_LIST
beep

@SET_STATUS_LIST
trans_flow

@OUTPUT_EVENT_LIST
abort_limit

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
ABORTING TEST!!! Transducer coolant flow is too low...

@END

###########################################################################

@INPUT_EVENT
trans_flow_ok

@RESET_STATUS_LIST
trans_flow

@SET_FALSE_LIST
beep

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Transducer coolant flow has returned to normal...

@END

###########################################################################

@INPUT_EVENT
trans_lvl_low

@IF_TRUE_LIST
key_switch
          
@SET_TRUE_LIST
beep

@SET_FALSE_LIST
xducer_clnt

@SET_STATUS_LIST
trans_cl_lvl

@OUTPUT_EVENT_LIST 
abort_limit 

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
LOW COOLANT - ABORTING TEST!! 

@END

###########################################################################

@INPUT_EVENT
trans_lvl_ok

@RESET_STATUS_LIST
trans_cl_lvl

@SET_FALSE_LIST
beep

@IF_SUCCESS_DISPLAY
NOTIFY

@IF_SUCCESS_DESCRIPTION
Coolant level returned to normal...

@END

#******************************************************************************
#******************************************************************************


